:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-products-stack{width:550px;position:relative}@media(max-width: 550px){.woocommerce-products-stack{width:100%}}.woocommerce-products-stack a{text-decoration:none;color:#007cba}.woocommerce-products-stack .woocommerce-list__item{margin-top:8px;border-radius:3px;border:1.5px solid #dcdcde}.woocommerce-products-stack .woocommerce-list__item:hover{background-color:#fff;border:1.5px solid #007cba}.woocommerce-products-stack .woocommerce-list__item:hover .woocommerce-list__item-title{color:#1e1e1e}.woocommerce-products-stack .woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-enter{transform:none}.woocommerce-products-stack .woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-enter-active{transform:none}.woocommerce-products-stack .woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-exit-active{display:none}.woocommerce-products-stack .woocommerce-list__item:first-child{margin-top:0}.woocommerce-products-stack .woocommerce-list__item.woocommerce-products-list__item-advert .woocommerce-list__item-before{background:none;border-radius:0;padding:0}.woocommerce-products-stack .woocommerce-list__item.woocommerce-products-list__item-advert .woocommerce-list__item-title span.printful-sponsored__text{display:flex;flex-direction:row;align-items:center;gap:8px}.woocommerce-products-stack .woocommerce-list__item.woocommerce-products-list__item-advert .woocommerce-label{background-color:rgba(var(--wp-admin-theme-color--rgb), 0.1);color:var(--wp-admin-theme-color, #000);border-radius:2px;padding:4px 8px;font-size:12px;font-weight:400;line-height:16px}.woocommerce-products-stack .woocommerce-list__item-inner{padding:20px}.woocommerce-products-stack .woocommerce-list__item-inner:focus{box-shadow:none}.woocommerce-products-stack .woocommerce-list__item-before{background:#f0f6fc;padding:8px;border-radius:50%}.woocommerce-products-stack .woocommerce-list__item-title{color:#1e1e1e;line-height:16px;font-weight:600}.woocommerce-products-stack .woocommerce-list__item-content{color:#757575;line-height:16px;font-weight:400}.woocommerce-products-stack .woocommerce-list__item-after svg{fill:#949494}.woocommerce-products-stack .woocommerce-stack__other-options{display:block;margin-top:20px;margin-bottom:4px;color:#757575;line-height:16px}.woocommerce-products-stack .woocommerce-stack__overlay-spinner{position:absolute;top:0;left:0;right:0;bottom:0;background-color:rgba(255,255,255,.8);display:flex;justify-content:center;align-items:center;z-index:999}.woocommerce-products-stack .woocommerce-stack__overlay-spinner .list-overlay{position:relative}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-products-card-list a{color:#007cba}.woocommerce-products-card-list .woocommerce-list{display:grid;grid-template-columns:auto auto;grid-column-gap:16px;grid-row-gap:24px;justify-content:center}.woocommerce-products-card-list .woocommerce-list__item{float:left;border-radius:3px;border:1.5px solid #dcdcde;width:263px;height:226px;text-align:center;align-items:start}.woocommerce-products-card-list .woocommerce-list__item:hover{background-color:#fff;border:1.5px solid #007cba}.woocommerce-products-card-list .woocommerce-list__item:hover .woocommerce-list__item-title{color:#1e1e1e}.woocommerce-products-card-list .woocommerce-list__item .woocommerce-list__item-inner{padding-top:40px;flex-flow:wrap;justify-content:center}.woocommerce-products-card-list .woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-enter{transform:none;transition:none}.woocommerce-products-card-list .woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-enter-active{transform:none;transition:none}.woocommerce-products-card-list .woocommerce-list__item:not(.transitions-disabled).woocommerce-list__item-exit-active{display:none}.woocommerce-products-card-list .woocommerce-list__item>.woocommerce-list__item-inner{box-shadow:none}.woocommerce-products-card-list .woocommerce-list__item-text{margin-top:16px}.woocommerce-products-card-list .woocommerce-list__item-text .woocommerce-list__item-content{margin-top:16px}.woocommerce-products-card-list .woocommerce-list__item-before{margin-right:0;background:#f0f6fc;padding:8px;border-radius:50%}.woocommerce-products-card-list .woocommerce-list__item-title{color:#1e1e1e;line-height:16px;font-weight:600;text-transform:uppercase}.woocommerce-products-card-list .woocommerce-list__item-content{color:#757575;line-height:16px;font-weight:400}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-products-card-list .woocommerce-list__item-content a{display:block;text-decoration:none;margin-top:8px}.woocommerce-products-card-list ul li:nth-child(2) .woocommerce-list__item-inner{padding:40px 17px 16px 17px}.woocommerce-task-import-products{max-width:544px;margin:auto}.woocommerce-task-import-products h1{text-align:center;padding:0 0 32px 0}.woocommerce-task-import-products button{color:var(--wp-admin-theme-color)}.woocommerce-task-import-products button:focus:not(:disabled){outline:none;box-shadow:none}.woocommerce-task-import-products .woocommerce-task-import-products-stacks{display:flex;flex-wrap:wrap;justify-content:center;padding:25px 0 12px 0}.woocommerce-task-import-products .woocommerce-task-import-products-stacks .woocommerce-list__item .woocommerce-list__item-title{color:#1e1e1e}.woocommerce-task-import-products .woocommerce-task-import-products-stacks .woocommerce-list__item .woocommerce-list__item-content{color:#757575}.woocommerce-task-import-products .woocommerce-task-import-products-stacks .woocommerce-list__item-before{border:0;background:none}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}.woocommerce-products-load-sample-product-modal-overlay{top:0;background:rgba(255,255,255,.8)}@media(min-width: 783px){.woocommerce-products-load-sample-product-modal-overlay{left:35px}}@media(min-width: 960px){.woocommerce-products-load-sample-product-modal-overlay{left:160px}}.woocommerce-products-load-sample-product-modal{background:rgba(0,0,0,0);box-shadow:none}.woocommerce-products-load-sample-product-modal .components-modal__header{display:none}.woocommerce-products-load-sample-product-modal .components-modal__content,.woocommerce-products-load-sample-product-modal .components-modal__header+div{display:flex;flex-direction:column;align-items:center;justify-content:center;margin:0}.woocommerce-products-load-sample-product-modal .woocommerce-load-sample-product-modal__title{color:#1e1e1e;font-weight:400;font-size:24px;line-height:32px;margin-top:32px}.woocommerce-products-load-sample-product-modal .woocommerce-load-sample-product-modal__description{color:#757575;font-weight:400;font-size:16px;line-height:24px;margin-top:12px}
:root{--wp-admin-theme-color: #007cba;--wp-admin-theme-color--rgb: 0, 124, 186;--wp-admin-theme-color-darker-10: #006ba1;--wp-admin-theme-color-darker-10--rgb: 0, 107, 161;--wp-admin-theme-color-darker-20: #005a87;--wp-admin-theme-color-darker-20--rgb: 0, 90, 135;--wp-admin-border-width-focus: 2px}@media(min-resolution: 192dpi){:root{--wp-admin-border-width-focus: 1.5px}}@media(min-width: 783px){.woocommerce-products-load-sample-product-confirm-modal-overlay{left:35px}}@media(min-width: 960px){.woocommerce-products-load-sample-product-confirm-modal-overlay{left:160px}}.woocommerce-products-load-sample-product-confirm-modal .components-truncate.components-text.woocommerce-confirmation-modal__message{color:#50575e}.woocommerce-products-load-sample-product-confirm-modal .woocommerce-confirmation-modal-actions{display:flex;justify-content:flex-end;margin-top:16px}.woocommerce-products-load-sample-product-confirm-modal .woocommerce-confirmation-modal-actions button{margin-left:16px}
